from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, File, Float, Int, String

Cestats_V0_1_0 = CommandToolBuilder(tool="cestats", base_command=["cestats"], inputs=[ToolInput(tag="in_overwrite", input_type=Boolean(optional=True), prefix="--overwrite", doc=InputDocumentation(doc="Allow existing outputs to be overwritten.")), ToolInput(tag="in_debug", input_type=Boolean(optional=True), prefix="--debug", doc=InputDocumentation(doc="Print out information about the files that are\nbeing read in and used for the calculations.")), ToolInput(tag="in_expert", input_type=Boolean(optional=True), prefix="--expert", doc=InputDocumentation(doc="I will consider you an expert user and NOT warn\nyou if you try to compute statistics from REMD-based\nfiles before using --fix-remd [NOT default behavior]")), ToolInput(tag="in_novice", input_type=Boolean(optional=True), prefix="--novice", doc=InputDocumentation(doc="I will warn you if you try to use REMD-based files\nto compute statistics. [Default behavior]")), ToolInput(tag="in_ce_in", input_type=File(optional=True), prefix="--cein", doc=InputDocumentation(doc="Input cein or cpein file (from pmemd or sander) with titrating residue\ninformation.")), ToolInput(tag="in_time_step", input_type=Float(optional=True), prefix="--time-step", doc=InputDocumentation(doc="This is the time step in ps you used in your simulations.\nIt will be used to print data as a function of time.\nDefault is 2 fs (0.002)")), ToolInput(tag="in_cal_ceo_output", input_type=File(optional=True), prefix="--calceo-output", doc=InputDocumentation(doc="File to which the standard `calceo'-type statistics\nare written. Default is stdout")), ToolInput(tag="in_running_avg_out", input_type=File(optional=True), prefix="--running-avg-out", doc=InputDocumentation(doc="Output file where the running averages of time series\ndata for each residue is printed (see [Output Options]\nbelow for details). Default is [running_avgs.dat]")), ToolInput(tag="in_chunk_out", input_type=File(optional=True), prefix="--chunk-out", doc=InputDocumentation(doc="Output file where the time series data calculated\nover chunks of the simulation are printed (see\n[Output Options] below for details).\nDefault is [chunk.dat]")), ToolInput(tag="in_cumulative_out", input_type=File(optional=True), prefix="--cumulative-out", doc=InputDocumentation(doc="Output file where the cumulative time series data\nis printed (see [Output Options] below for details).\nDefault is [cumulative.dat]")), ToolInput(tag="in_population", input_type=File(optional=True), prefix="--population", doc=InputDocumentation(doc="Output file where reduction state populations are\nprinted for every state of every residue.")), ToolInput(tag="in_conditional_output", input_type=File(optional=True), prefix="--conditional-output", doc=InputDocumentation(doc="Output file with requested conditional probabilities.\nDefault is [conditional_prob.dat].")), ToolInput(tag="in_chunk_conditional", input_type=File(optional=True), prefix="--chunk-conditional", doc=InputDocumentation(doc="Prints a time series of the conditional probabilities over\na trajectory split up into chunks.")), ToolInput(tag="in_verbose", input_type=File(optional=True), prefix="--verbose", doc=InputDocumentation(doc="Controls how much information is printed to the\ncalceo-style output file. Options are:\n(0) Just print fraction reduced. [Default]\n(1) Print everything calceo prints.")), ToolInput(tag="in_interval", input_type=Int(optional=True), prefix="--interval", doc=InputDocumentation(doc="An interval between which to print out time series data\nlike `chunks', `cumulative' data, and running averages.\nIt is also used as the 'window' of the conditional\nprobability time series (--chunk-conditional).\nDefault [1000]")), ToolInput(tag="in_reduced", input_type=Boolean(optional=True), prefix="--reduced", doc=InputDocumentation(doc="Print out reduction fraction instead of oxidation\nfraction in time series data (Default behavior).")), ToolInput(tag="in_oxidized", input_type=Boolean(optional=True), prefix="--oxidized", doc=InputDocumentation(doc="Print out oxidation fraction instead of reduction\nfraction in time series data.")), ToolInput(tag="in_eo", input_type=Boolean(optional=True), prefix="--Eo", doc=InputDocumentation(doc="Print predicted Eos (via Nernst equation) in place\nof fraction reduced or oxidized. NOT default behavior.")), ToolInput(tag="in_cal_ceo", input_type=Boolean(optional=True), prefix="--calceo", doc=InputDocumentation(doc="Triggers the calceo-style output [On by default]")), ToolInput(tag="in_no_cal_ceo", input_type=Boolean(optional=True), prefix="--no-calceo", doc=InputDocumentation(doc="Turns off the calceo-style output")), ToolInput(tag="in_running_avg", input_type=Int(optional=True), prefix="--running-avg", doc=InputDocumentation(doc="Defines a window size for a moving, running average\ntime series. <WINDOW> is the number of MD steps (NOT\nthe number of MC exchange attempts).")), ToolInput(tag="in_chunk", input_type=Int(optional=True), prefix="--chunk", doc=InputDocumentation(doc="Computes the time series data over a chunk of the\nsimulation of size <WINDOW> time steps. See above for\ndetails.")), ToolInput(tag="in_cumulative", input_type=Boolean(optional=True), prefix="--cumulative", doc=InputDocumentation(doc="Computes the cumulative average time series data (see above\nfor options) over the course of the trajectory.")), ToolInput(tag="in_fix_re_md", input_type=String(optional=True), prefix="--fix-remd", doc=InputDocumentation(doc="This option will trigger cestats to reassemble the\ntitration data into Redox potential specific ensembles. This\nis an exclusive mode of the program---no other\nanalyses will be done.")), ToolInput(tag="in_conditional", input_type=Int(optional=True), prefix="--conditional", doc=InputDocumentation(doc="Evaluates conditional probabilities. CONDITIONAL should be a\nstring of the format:\n<resid>:<state>,<resid>:<state>,...\nor\n<resid>:REDU,<resid>:OXID,...\nor\n<resid>:<state1>;<state2>,<resid>:REDU,...\nWhere <resid> is the residue number in the prmtop (NOT the\ncein) and <state> is either the state number or p (reduced)\nor d (oxidized), case-insensitive")), ToolInput(tag="in_v", input_type=Boolean(optional=True), prefix="-V", doc=InputDocumentation(doc=""))], outputs=[ToolOutput(tag="out_running_avg_out", output_type=File(optional=True), selector=InputSelector(input_to_select="in_running_avg_out", type_hint=File()), doc=OutputDocumentation(doc="Output file where the running averages of time series\ndata for each residue is printed (see [Output Options]\nbelow for details). Default is [running_avgs.dat]")), ToolOutput(tag="out_chunk_out", output_type=File(optional=True), selector=InputSelector(input_to_select="in_chunk_out", type_hint=File()), doc=OutputDocumentation(doc="Output file where the time series data calculated\nover chunks of the simulation are printed (see\n[Output Options] below for details).\nDefault is [chunk.dat]")), ToolOutput(tag="out_cumulative_out", output_type=File(optional=True), selector=InputSelector(input_to_select="in_cumulative_out", type_hint=File()), doc=OutputDocumentation(doc="Output file where the cumulative time series data\nis printed (see [Output Options] below for details).\nDefault is [cumulative.dat]")), ToolOutput(tag="out_population", output_type=File(optional=True), selector=InputSelector(input_to_select="in_population", type_hint=File()), doc=OutputDocumentation(doc="Output file where reduction state populations are\nprinted for every state of every residue.")), ToolOutput(tag="out_conditional_output", output_type=File(optional=True), selector=InputSelector(input_to_select="in_conditional_output", type_hint=File()), doc=OutputDocumentation(doc="Output file with requested conditional probabilities.\nDefault is [conditional_prob.dat].")), ToolOutput(tag="out_verbose", output_type=File(optional=True), selector=InputSelector(input_to_select="in_verbose", type_hint=File()), doc=OutputDocumentation(doc="Controls how much information is printed to the\ncalceo-style output file. Options are:\n(0) Just print fraction reduced. [Default]\n(1) Print everything calceo prints."))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Cestats_V0_1_0().translate("wdl", allow_empty_container=True)

